import React from 'react'
import { getClassName, getMergedClassNames, SelectMenuProps } from '../../../common'
import { TranscriptionStatus } from '../../../../store'
import zocksStyle from './AudioControlMenu.module.scss'

export const DefaultAudioControlMenu: React.FC<SelectMenuProps> = ({ styles, menuItems, onMenuItemClick }) => {
  const mergedStyles = getMergedClassNames(zocksStyle, styles)

  return (
    <div className={getClassName('select-button__popover-container', mergedStyles)}>
      <ul className={getClassName('select-button__popover-list', mergedStyles)}>
        <li
          className={`${getClassName('select-button__popover-item', mergedStyles)} ${getClassName(
            'audio-control-menu-item',
            mergedStyles
          )}`}
        >
          Microphone Settings
        </li>
        {menuItems.length > 0
          ? menuItems.map((item, i) => {
              return (
                <li
                  className={getClassName('select-button__popover-item', mergedStyles)}
                  key={i}
                  onClick={() => onMenuItemClick(item)}
                >
                  {item.label}
                  {item.selected ? <i className={getClassName('icon-check-mark', mergedStyles)} /> : null}
                </li>
              )
            })
          : null}
      </ul>
    </div>
  )
}

export const TranscriptionAudioControlMenu = (
  transcriptionStatus: TranscriptionStatus,
  toggleTranscription: () => Promise<void>
): React.FC<SelectMenuProps> => {
  return ({ styles, menuItems, onMenuItemClick, hideMenu }) => {
    const onTranscriptionClick = async () => {
      hideMenu()
      await toggleTranscription()
    }

    const { autoEnabled, serviceEnabled, displayTranscriptions } = transcriptionStatus
    const enableButtonText = autoEnabled ? 'Show Transcriptions' : 'Enable Transcription'
    const disableButtonText = autoEnabled ? 'Hide Transcriptions' : 'Disable Transcription'
    const showDisableButton = autoEnabled ? displayTranscriptions : serviceEnabled

    const mergedStyles = getMergedClassNames(zocksStyle, styles)

    return (
      <div className={getClassName('select-button__popover-container', mergedStyles)}>
        <ul className={getClassName('select-button__popover-list', mergedStyles)}>
          <li
            className={`${getClassName('select-button__popover-item', mergedStyles)} ${getClassName(
              'audio-control-menu-item',
              mergedStyles
            )}`}
          >
            Microphone Settings
          </li>
          {menuItems.length > 0
            ? menuItems.map((item, i) => {
                return (
                  <li
                    className={getClassName('select-button__popover-item', mergedStyles)}
                    key={i}
                    onClick={() => onMenuItemClick(item)}
                  >
                    {item.label}
                    {item.selected ? <i className={getClassName('icon-check-mark', mergedStyles)} /> : null}
                  </li>
                )
              })
            : null}
          <li
            className={`${getClassName('select-button__popover-item', mergedStyles)} ${getClassName(
              'transcription-menu-item',
              mergedStyles
            )}`}
            onClick={onTranscriptionClick}
          >
            {showDisableButton ? (
              <>
                <i className={getClassName('icon-close', mergedStyles)} />
                {disableButtonText}
              </>
            ) : (
              <>
                <i className={getClassName('icon-message', mergedStyles)} />
                {enableButtonText}
              </>
            )}
          </li>
        </ul>
      </div>
    )
  }
}
