import { useLocalMedia, useLocalVirtualBackgrounds } from '../../store'

export const useJoinPage = (videoEnabledByDefault?: boolean, audioEnabledByDefault?: boolean) => {
  const {
    localAudioStream,
    localVideoStream,
    currentAudioDeviceId,
    currentVideoDeviceId,
    toggleLocalAudioStream,
    toggleLocalVideoStream,
    selectAudioDevice,
    selectVideoDevice,
  } = useLocalMedia(videoEnabledByDefault, audioEnabledByDefault)

  const {
    availableVirtualBackgrounds,
    currentVirtualBackground,
    virtualBackgroundStream,
    changeVirtualBackground,
    stopLocalVirtualBackground,
  } = useLocalVirtualBackgrounds()

  const afterJoinCleanUp = () => {
    localAudioStream && toggleLocalAudioStream()
    localVideoStream && toggleLocalVideoStream()
    currentVirtualBackground && stopLocalVirtualBackground()
  }

  const videoStream = localVideoStream || virtualBackgroundStream
  const localMediaJoinOptions = {
    audioDeviceSettings: localAudioStream && currentAudioDeviceId ? { deviceId: currentAudioDeviceId } : undefined,
    videoDeviceSettings: videoStream && currentVideoDeviceId ? { deviceId: currentVideoDeviceId } : undefined,
    virtualBackground: currentVirtualBackground?.type ?? null,
  }

  return {
    localMedia: {
      localAudioStream,
      localVideoStream,
      currentVirtualBackground,
      availableVirtualBackgrounds,
      virtualBackgroundStream,
      currentAudioDeviceId,
      currentVideoDeviceId,
      toggleLocalAudioStream,
      toggleLocalVideoStream,
      changeVirtualBackground,
      stopLocalVirtualBackground,
      selectAudioDevice,
      selectVideoDevice,
      localMediaJoinOptions,
    },
    afterJoinCleanUp,
  }
}
